@@ -23,7 +23,7 @@ urlpatterns = [
     re_path(r'^permission_value_list/?$', PermissionValueAPIView.list, ),  # 权限值列表
     re_path(r'^permission_value/?(?P<id>\d+)?$', PermissionValueAPIView.as_view(), ),  # 权限值增删改
 
-    re_path(r'^has_permission_value/?$', PermissionValueAPIView.permission, ),  # 用户权限判断
+    re_path(r'^user_permission_tree/?$', PermissionValueAPIView.get_user_permission_tree, ),  # 用户权限判断
 
     # 分组相关的接口
     re_path(r'^get_user_from_list/(?P<user_group_id>\d+)?$', GroupAPIView.get_user_from_list, ),  # 根据分组ID,获取绑定用户ID，测试接口
